@@ -117,11 +117,21 @@ struct cli_md5_node {
     char *virname, *viralias;
     unsigned char *md5;
     unsigned int size;
+    unsigned short fp;
     struct cli_md5_node *next;
 };
 
+struct cli_meta_node {
+    int csize, size, method;
+    unsigned int crc32, fileno, encrypted, maxdepth;
+    char *filename, *virname;
+    struct cli_meta_node *next;
+};
+
 struct cl_node {
+    unsigned int refcount;
     unsigned int maxpatlen; /* maximal length of pattern in db */
+    unsigned short sdb;
 
     /* Extended Boyer-Moore */
     int *bm_shift;
@@ -133,18 +143,25 @@ struct cl_node {
 
     /* MD5 */
     struct cli_md5_node **md5_hlist;
+
+    /* Zip metadata */
+    struct cli_meta_node *zip_mlist;
+
+    /* RAR metadata */
+    struct cli_meta_node *rar_mlist;
+
 };
 
 struct cl_limits {
-    int maxreclevel; /* maximal recursion level */
-    int maxfiles; /* maximal number of files to be
-		   * scanned within an archive
-		   */
-    int maxratio; /* maximal compression ratio */
-    short archivememlim; /* limit memory usage for bzip2 (0/1) */
-    long int maxfilesize; /* files in an archive larger than
-			   * this value will not be scanned
-			   */
+    unsigned int maxreclevel; /* maximal recursion level */
+    unsigned int maxfiles; /* maximal number of files to be
+			    * scanned within an archive
+			    */
+    unsigned int maxratio; /* maximal compression ratio */
+    unsigned short archivememlim; /* limit memory usage for bzip2 (0/1) */
+    unsigned long int maxfilesize; /* files in an archive larger than
+				    * this limit will not be scanned
+				    */
 };
 
 struct cl_stat {
@@ -180,6 +197,7 @@ extern const char *cl_retver(void);
 extern int cl_loaddb(const char *filename, struct cl_node **root, unsigned int *signo);
 extern int cl_loaddbdir(const char *dirname, struct cl_node **root, unsigned int *signo);
 extern const char *cl_retdbdir(void);
+extern struct cl_node *cl_dup(struct cl_node *root);
 
 /* CVD */
 extern struct cl_cvd *cl_cvdhead(const char *file);
